@@ -1,3 +1,4 @@
+import builtins
 import datetime
 from files_sdk.api import Api
 from files_sdk.list_obj import ListObj
@@ -13,7 +14,8 @@ class BundleRegistration:
         'inbox_code': None,     # string - InboxRegistration cookie code, if there is an associated InboxRegistration
         'clickwrap_body': None,     # string - Clickwrap text that was shown to the registrant
         'form_field_set_id': None,     # int64 - Id of associated form field set
-        'form_field_data': None,     # string - Data for form field set with form field ids as keys and user data as values
+        'form_field_data': None,     # object - Data for form field set with form field ids as keys and user data as values
+        'bundle_code': None,     # string - Bundle URL code
         'bundle_id': None,     # int64 - Id of associated bundle
         'bundle_recipient_id': None,     # int64 - Id of associated bundle recipient
     }
@@ -36,7 +38,7 @@ class BundleRegistration:
 
 # Parameters:
 #   user_id - int64 - User ID.  Provide a value of `0` to operate the current session's user.
-#   cursor - string - Used for pagination.  Send a cursor value to resume an existing list from the point at which you left off.  Get a cursor from an existing list via the X-Files-Cursor-Next header.
+#   cursor - string - Used for pagination.  Send a cursor value to resume an existing list from the point at which you left off.  Get a cursor from an existing list via either the X-Files-Cursor-Next header or the X-Files-Cursor-Prev header.
 #   per_page - int64 - Number of records to show per page.  (Max: 10,000, 1,000 or less is recommended).
 #   bundle_id - int64 - ID of the associated Bundle
 def list(params = None, options = None):
