@@ -8,8 +8,8 @@ class Status:
         'code': None,     # int64 - Status HTTP code
         'message': None,     # string - Error message
         'status': None,     # string - Status message
-        'data': None,     # Additional data
-        'errors': None,     # A list of api errors
+        'data': None,     # Auto - Additional data
+        'errors': None,     # Errors - A list of api errors
         'clickwrap_id': None,     # int64 - Required Clickwrap id
         'clickwrap_body': None,     # string - Required Clickwrap body
     }
